AstMap class

Inheritance
Available extensions

Constructors

AstMap({AstType keyType = const AstObject(), AstType valueType = const AstObject(), bool maybeNull = false, List<bool> genericsMaybeNull = const <bool>[]})

Properties

genericMaybeNull → List<bool>
finalinherited
generics → List<AstType>
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
keepRaw → bool
finalinherited
keyType → AstType
final
maybeNull → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueType → AstType
final

Methods

astType() → String
override
containsCustomType() → bool

Available on AstType, provided by the AstTypeExtension extension

convertDartJson2Obj({String vname = _replyPlaceholder}) → String?

Available on AstType, provided by the AstTypeExtension extension

convertDartObj2Json(String valueName) → String

Available on AstType, provided by the AstTypeExtension extension

convertJavaJson2Obj({String vname = '[message objectForKey:@"data"]', bool hasDefaultValue = true, bool showGenerics = false}) → String

Available on AstType, provided by the AstTypeExtension extension

convertJavaObj2Json(String valueName) → String

Available on AstType, provided by the AstTypeExtension extension

convertOcJson2Obj({String vname = '[message objectForKey:@"data"]'}) → String?

Available on AstType, provided by the AstTypeExtension extension

convertOcObj2Json(String valueName) → String

Available on AstType, provided by the AstTypeExtension extension

dartDefault() → String
override
dartType({bool showGenerics = false}) → String
override
hasMessagerAnno() → bool

Available on AstType, provided by the AstTypeExtension extension

javaDefault() → String
override
javaNewInstance() → String
override
javaType({bool showGenerics = false}) → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ocType({bool showGenerics = false}) → String
override
realType() → AstType
inherited
reassignAstCustomType(String name) → void

Available on AstType, provided by the AstTypeExtension extension

recursiveCustomType() → List<AstCustomType>

Available on AstType, provided by the AstTypeExtension extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited