Variable class

Inheritance

Constructors

Variable(AstType type, String name, {List<String> codeComments = const <String>[]})

Properties

codeComments ↔ List<String>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ AstType
getter/setter pair

Methods

javaDeclaration({bool newInstance = false}) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

keywordSpace → const String