Method class

Inheritance
Available extensions

Constructors

Method({String name = '', AstType returnType = const AstVoid(), List<Variable> parameters = const [], bool ignoreError = false, bool isAsync = false, List<String> codeComments = const <String>[]})
Method.copy(Method method)

Properties

codeComments ↔ List<String>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasMessagerAnno → bool

Available on Method, provided by the MethodExtension extension

Check if the user-declared interface has the RequiredMessager annotation.
no setter
ignoreError ↔ bool
getter/setter pair
isAsync ↔ bool
getter/setter pair
lastArgument → Variable?

Available on Method, provided by the MethodExtension extension

Return the last parameter from the 'Method' parameter list generated by Unify's Analyzer.
no setter
name ↔ String
getter/setter pair
parameters ↔ List<Variable>
getter/setter pair
realDartMethodParams → List<Variable>

Available on Method, provided by the MethodExtension extension

Return the real parameters of the user-declared Dart interface.
no setter
returnType ↔ AstType
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited