Model class

Inheritance
Mixed-in types

Constructors

Model(String name, InputFile inputFile, {List<Variable> fields = const [], bool isEnum = false, List<String> codeComments = const <String>[]})

Properties

codeComments ↔ List<String>
getter/setter pair
fields ↔ List<Variable>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputFile ↔ InputFile
getter/setter pair
isEnum ↔ bool
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dartDecodedFuncName(bool isEnum, String template) → String
inherited
dartEncodedFuncName(bool isEnum) → String
inherited
javaDecodedFuncName(bool isEnum, String template) → String
inherited
javaEncodedFuncName(bool isEnum) → String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited