Module class

Inheritance

Constructors

Module(InputFile inputFile, {String name = '', List<Method> methods = const [], List<String> codeComments = const <String>[]})

Properties

codeComments ↔ List<String>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputFile ↔ InputFile
getter/setter pair
methods ↔ List<Method>
List of methods inside the API.
getter/setter pair
name ↔ String
The name of the API.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited