UniAPIOptions class

Constructors

UniAPIOptions()
UniAPIOptions.fromParser(ArgResults results)
factory

Properties

dartNullSafety ↔ bool
getter/setter pair
dartOutput ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
javaOutputPath ↔ String
getter/setter pair
javaPackageName ↔ String
getter/setter pair
javaUniAPIPrefix ↔ String
getter/setter pair
objcOutput ↔ String
getter/setter pair
objcUniAPIPrefix ↔ String
getter/setter pair
projectPath ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tempDir ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getParams(ArgResults results, String key) → String