ModuleGenerator class abstract

Constructors

ModuleGenerator()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

dartCallbackManagerCode(UniAPIOptions options, {List<Model>? models}) → String
dartCode(Module module, UniAPIOptions options) → String
getSetupFuncParams(String protocolName) → List<Variable>
javaCode(Module module, UniAPIOptions options) → String
javaRegisterCode(Module module, UniAPIOptions options) → String
ocHeader(Module module, UniAPIOptions options) → String
ocSource(Module module, UniAPIOptions options) → String
productPath(String outPath, String inputFilePath) → String