CodeUnitMixin mixin

Superclass constraints
Mixin applications
Available extensions

Properties

depth → int
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → String
inherited
cloneDartCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

collectModels(List<String> names) → List<Model>
depthTabs() → String
inherited
handlerJavaCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

handlerOCCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited