DartConstructor class

Inheritance
Available extensions

Constructors

DartConstructor(String className, List<Variable> params, {int depth = 0})

Properties

body ↔ FunctionBodyBuilder?
getter/setter pairinherited
depth → int
finalinherited
functionName ↔ String
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isAbstract ↔ bool
getter/setter pairinherited
isAsync ↔ bool
getter/setter pairinherited
isConstructor ↔ bool
getter/setter pairinherited
isStatic ↔ bool
getter/setter pairinherited
params ↔ List<Variable>
getter/setter pairinherited
returnType ↔ AstType
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → String
inherited
cloneDartCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

depthTabs() → String
inherited
functionSignature() → String
inherited
handlerJavaCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

handlerOCCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited