JavaClass class

Inheritance
Implementers
Available extensions

Constructors

JavaClass({String className = '', String? parentClass, List<String> generics = const [], List<Variable> publicFields = const [], List<Variable> privateFields = const [], List<Variable> fieldGettersAndSetters = const [], InjectCodeUnit? injectedJavaCodes, List<Method> methods = const [], bool isPublic = false, bool isInterface = false, bool isStatic = false, bool hasToMap = false, bool hasFromMap = false, int depth = 0})

Properties

className ↔ String
getter/setter pair
depth → int
finalinherited
fieldGettersAndSetters ↔ List<Variable>
getter/setter pair
generics ↔ List<String>
getter/setter pair
hasFromMap ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasToMap ↔ bool
getter/setter pair
injectedJavaCodes ↔ InjectCodeUnit?
getter/setter pair
isInterface ↔ bool
getter/setter pair
isPublic ↔ bool
getter/setter pair
isStatic ↔ bool
getter/setter pair
methods ↔ List<Method>
getter/setter pair
parentClass ↔ String?
getter/setter pair
privateFields ↔ List<Variable>
getter/setter pair
publicFields ↔ List<Variable>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → String
override
classSignature() → OneLine
cloneDartCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

depthTabs() → String
inherited
fromMapFunc() → JavaFunction
getterAndSetters() → List<CodeUnit>
handlerJavaCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

handlerOCCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

javaPrivateFields() → List<CodeUnit>
javaPublicFields() → List<CodeUnit>
methodsInterfaces() → List<CodeUnit>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMapFunc() → JavaFunction
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited