JavaClassUniCallback class

Inheritance
Available extensions

Constructors

JavaClassUniCallback(String methodName, String paramName, AstType paramGeneric, {int depth = 0, String javaUniAPIPrefix = ''})

Properties

className ↔ String
getter/setter pairinherited
depth → int
finalinherited
fieldGettersAndSetters ↔ List<Variable>
getter/setter pairinherited
generics ↔ List<String>
getter/setter pairinherited
hasFromMap ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
hasToMap ↔ bool
getter/setter pairinherited
injectedJavaCodes ↔ InjectCodeUnit?
getter/setter pairinherited
isInterface ↔ bool
getter/setter pairinherited
isPublic ↔ bool
getter/setter pairinherited
isStatic ↔ bool
getter/setter pairinherited
methods ↔ List<Method>
getter/setter pairinherited
parentClass ↔ String?
getter/setter pairinherited
privateFields ↔ List<Variable>
getter/setter pairinherited
publicFields ↔ List<Variable>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → String
inherited
classSignature() → OneLine
inherited
cloneDartCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

depthTabs() → String
inherited
fromMapFunc() → JavaFunction
inherited
getterAndSetters() → List<CodeUnit>
inherited
handlerJavaCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

handlerOCCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

javaPrivateFields() → List<CodeUnit>
inherited
javaPublicFields() → List<CodeUnit>
inherited
methodsInterfaces() → List<CodeUnit>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMapFunc() → JavaFunction
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getName(String methodName, String paramName) → String
upperFirst(String name) → String