JavaFunction class

Inheritance
Implementers
Available extensions

Constructors

JavaFunction({String functionName = '', FunctionBodyBuilder? body, List<Variable> params = const [], AstType returnType = const AstVoid(), int depth = 0, bool isAbstract = false, bool isOverride = false, bool isPublic = false, bool isPrivate = false, bool isStatic = false, bool isConstruct = false, bool oneLine = false})

Properties

body ↔ FunctionBodyBuilder?
getter/setter pair
depth → int
finalinherited
functionName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAbstract ↔ bool
getter/setter pair
isConstruct ↔ bool
getter/setter pair
isOverride ↔ bool
getter/setter pair
isPrivate ↔ bool
getter/setter pair
isPublic ↔ bool
getter/setter pair
isStatic ↔ bool
getter/setter pair
oneLine ↔ bool
getter/setter pair
params ↔ List<Variable>
getter/setter pair
returnType ↔ AstType
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → String
override
cloneDartCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

depthTabs() → String
inherited
functionSignature() → String
handlerJavaCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

handlerOCCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited