JavaCustomNestedImports class

嵌套 Model 依赖

Inheritance
Mixed-in types
Available extensions

Constructors

JavaCustomNestedImports(InputFile inputFile, UniAPIOptions options, {List<Variable> fields = const [], List<Method> methods = const [], List<String> excludeImports = const [], int depth = 0})

Properties

depth → int
finalinherited
excludeImports ↔ List<String>
getter/setter pair
fields → List<Variable>
final
hashCode → int
The hash code for this object.
no setterinherited
inputFile → InputFile
final
methods → List<Method>
final
modelSet ↔ Set<String>
getter/setter pair
options → UniAPIOptions
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → String
override
cloneDartCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

collectModels(List<String> names) → List<Model>
inherited
depthTabs() → String
inherited
handlerJavaCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

handlerOCCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited