JavaModelImport class

基于 Model 自动生成 import

Inheritance
Available extensions

Constructors

JavaModelImport(Model model, UniAPIOptions options, int depth)

Properties

depth → int
finalinherited
fullClassName ↔ String
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → String
inherited
cloneDartCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

depthTabs() → String
inherited
handlerJavaCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

handlerOCCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited