OCClassDeclaration class

Inheritance
Available extensions

Constructors

OCClassDeclaration({String className = '', String parentClass = '', List<Variable> properties = const [], bool isInterface = false, bool isProtocol = false, bool hasExtension = false, String extensionName = '', List<Method> instanceMethods = const [], List<Method> classMethods = const [], int depth = 0})

Properties

classMethods ↔ List<Method>
getter/setter pair
className ↔ String
getter/setter pair
depth → int
finalinherited
extensionName ↔ String
getter/setter pair
hasExtension ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceMethods ↔ List<Method>
getter/setter pair
isInterface ↔ bool
getter/setter pair
isProtocol ↔ bool
getter/setter pair
parentClass ↔ String
getter/setter pair
properties ↔ List<Variable>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → String
override
classMethodInterfaces() → List<CodeUnit>
classSignature() → OneLine
cloneDartCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

depthTabs() → String
inherited
handlerJavaCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

handlerOCCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

instanceMethodInterfaces() → List<CodeUnit>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ocFields() → List<CodeUnit>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

keywordSpace → const String