OCClassUniCallback class

Constructors

OCClassUniCallback(String methodName, String paramName, {AstType paramGeneric = const AstVoid(), int depth = 0, String objcUniAPIPrefix = ''})

Properties

depth ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
methodName ↔ String
getter/setter pair
objcUniAPIPrefix ↔ String
getter/setter pair
paramGeneric ↔ AstType
getter/setter pair
paramName ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getImplementationDeclaration() → OCClassDeclaration
生成 UniCallback 在实现文件中的私有类声明
getImplementationImplementation() → OCClassImplementation
生成 UniCallback 在实现文件中的类实现
getPublicDeclaration() → OCClassDeclaration
生成 UniCallback 在头文件中的类声明
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

genImplementationDeclarations(List<Method> methods, {int depth = 0}) → List<CodeUnit>
genImplementationImplementation(List<Method> methods, {int depth = 0, UniAPIOptions? options}) → List<CodeUnit>
genPublicDeclarations(List<Method> methods, {int depth = 0, UniAPIOptions? options}) → List<CodeUnit>
传入模块方法列表,生成头文件类声明列表
getName(String methodName, String paramName) → String
upperFirst(String name) → String