OCFunction class

Inheritance
Implementers
Available extensions

Constructors

OCFunction({String functionName = '', List<Variable> params = const [], bool isInstanceMethod = false, bool isClassMethod = false, bool isDeclaration = false, bool isCFlavor = false, bool isExternal = false, bool isStatic = false, FunctionBodyBuilder? body, AstType returnType = const AstVoid(), int depth = 0})

Properties

body ↔ FunctionBodyBuilder?
getter/setter pair
depth → int
finalinherited
functionName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isCFlavor ↔ bool
getter/setter pair
isClassMethod ↔ bool
getter/setter pair
isDeclaration ↔ bool
getter/setter pair
isExternal ↔ bool
getter/setter pair
isInstanceMethod ↔ bool
getter/setter pair
isStatic ↔ bool
getter/setter pair
params ↔ List<Variable>
getter/setter pair
returnType ↔ AstType
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → String
override
cloneDartCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

depthTabs() → String
inherited
functionSignature() → String
functionSignatureC() → String
functionSignatureOC() → String
handlerJavaCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

handlerOCCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited