OCFunctionCall class

Inheritance
Available extensions

Constructors

OCFunctionCall({String instanceName = '', String functionName = '', List<OCFunctionCallRealParam> params = const [], bool ignoreError = false, int depth = 0})

Properties

depth → int
finalinherited
functionName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ignoreError ↔ bool
getter/setter pair
instanceName ↔ String
getter/setter pair
params ↔ List<OCFunctionCallRealParam>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → String
override
cloneDartCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

depthTabs() → String
inherited
handlerJavaCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

handlerOCCollectionType({List<Method> methods = const [], List<Variable> fields = const [], int depth = 0}) → List<OneLine>

Available on CodeUnit, provided by the CodeUnitExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited