InputFile class

Constructors

InputFile({String path = '', String absolutePath = '', String relativePath = '', String name = '', List<String> parts = const []})

Properties

absolutePath → String
final
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pair
parts ↔ List<String>
getter/setter pair
pascalName → String
no setter
path ↔ String
getter/setter pair
relativePath → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

javaNativeRegisterPath() → String
javaPackagePostfix() → String
javaPath() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
objcHeaderPath() → String
objcSourcePath() → String
sameParts(InputFile? inputFile) → bool
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited