UniFlutterModuleWorkRunner class

Inheritance

Constructors

UniFlutterModuleWorkRunner(Module module, UniAPIOptions options)

Properties

hashCode → int
The hash code for this object.
no setterinherited
module → Module
finalinherited
options → UniAPIOptions
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dartGenerator() → void
override
detectErrorInJava(String clsName, String pascalFileName, {String fileName = '', String absolutePath = ''}) → void
inherited
javaGenerator() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
objcGenerator() → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited